@@ -697,7 +697,21 @@ var app = window.Yancy = new Vue({
         },
 
         updateHash: function () {
-            location.hash = "/" + this.currentSchemaName + "/" + this.currentPage;
+            var newHash = "#/" + this.currentSchemaName + "/" + this.currentPage,
+                state = {
+                    schema: this.currentSchemaName,
+                    page: this.currentPage
+                };
+            console.log( newHash, location.hash );
+            if ( location.hash == newHash ) {
+                return;
+            }
+            else if ( !location.hash ) {
+                history.replaceState( state, '', newHash );
+            }
+            else {
+                history.pushState( state, '', newHash );
+            }
         },
 
         saveItem: function (i) {
